For further details please consult the OSQP documentation: https://osqp.org/
osqpSettings(
rho = 0.1,
rho_is_vec = TRUE,
sigma = 1e-06,
max_iter = 4000L,
eps_abs = 0.001,
eps_rel = 0.001,
eps_prim_inf = 1e-04,
eps_dual_inf = 1e-04,
alpha = 1.6,
linsys_solver = c(OSQP_DIRECT_SOLVER = 1L),
delta = 1e-06,
polishing = FALSE,
polish_refine_iter = 3L,
verbose = TRUE,
scaled_termination = FALSE,
check_termination = 25L,
check_dualgap = TRUE,
warm_starting = TRUE,
scaling = 10L,
adaptive_rho = 1L,
adaptive_rho_interval = 50L,
adaptive_rho_tolerance = 5,
adaptive_rho_fraction = 0.4,
cg_max_iter = 20L,
cg_tol_reduction = 10L,
cg_tol_fraction = 0.15,
cg_precond = c(OSQP_DIAGONAL_PRECONDITIONER = 1L),
profiler_level = 0L,
time_limit = 1e+10,
polish = NULL,
warm_start = NULL
)ADMM step rho
boolean, whether rho is treated as a vector (per-constraint) or scalar
ADMM step sigma
maximum iterations
absolute convergence tolerance
relative convergence tolerance
primal infeasibility tolerance
dual infeasibility tolerance
relaxation parameter
which linear systems solver to use, 1=OSQP_DIRECT_SOLVER (QDLDL), 2=OSQP_INDIRECT_SOLVER
regularization parameter for polishing
boolean, polish ADMM solution
iterative refinement steps in polishing
boolean, write out progress
boolean, use scaled termination criteria
integer, check termination interval. If 0, termination checking is disabled
boolean, check duality gap termination criteria
boolean, warm start
heuristic data scaling iterations. If 0, scaling disabled
integer, rho adaptation strategy: 0=disabled, 1=iterations, 2=time, 3=KKT error
Number of iterations between rho adaptations rho. If 0, it is automatic
Tolerance X for adapting rho. The new rho has to be X times larger or 1/X times smaller than the current one to trigger a new factorization
Interval for adapting rho (fraction of the setup time)
maximum number of CG iterations (indirect solver only)
integer, number of consecutive zero CG iterations before the tolerance gets halved (indirect solver only)
CG tolerance fraction (indirect solver only)
preconditioner for CG method (indirect solver only): 0=none, 1=diagonal (Jacobi)
integer, level of detail for profiler annotations (0=off)
run time limit in seconds (1e10 effectively disables)
Deprecated. Use polishing instead.
Deprecated. Use warm_starting instead.